@@ -1,6 +1,6 @@
 from bitcash.format import verify_sig
 from bitcash.network.rates import SUPPORTED_CURRENCIES, set_rate_cache_time
 from bitcash.network.services import set_service_timeout
-from bitcash.wallet import Key, PrivateKey, PrivateKeyTestnet, wif_to_key
+from bitcash.wallet import Key, PrivateKey, PrivateKeyTestnet, PrivateKeyRegtest, wif_to_key
 
-__version__ = '0.5.4'
+__version__ = '0.6.0'
