@@ -80,6 +80,7 @@ class BitcoinDotComAPI():
     MAIN_TX_AMOUNT_API = MAIN_TX_API
     MAIN_RAW_API = MAIN_ENDPOINT + 'transaction/details/{}'
     TX_PUSH_PARAM = 'rawtx'
+
     TEST_ENDPOINT = 'https://trest.bitcoin.com/v2/'
     TEST_ADDRESS_API = TEST_ENDPOINT + 'address/details/{}'
     TEST_UNSPENT_API = TEST_ENDPOINT + 'address/utxo/{}'
@@ -88,6 +89,14 @@ class BitcoinDotComAPI():
     TEST_TX_AMOUNT_API = TEST_TX_API
     TEST_RAW_API = TEST_ENDPOINT + 'transaction/details/{}'
 
+    REGTEST_ENDPOINT = 'http://localhost:12500/v2/'
+    REGTEST_ADDRESS_API = REGTEST_ENDPOINT + 'address/details/{}'
+    REGTEST_UNSPENT_API = REGTEST_ENDPOINT + 'address/utxo/{}'
+    REGTEST_TX_PUSH_API = REGTEST_ENDPOINT + 'rawtransactions/sendRawTransaction/{}'
+    REGTEST_TX_API = REGTEST_ENDPOINT + 'transaction/details/{}'
+    REGTEST_TX_AMOUNT_API = REGTEST_TX_API
+    REGTEST_RAW_API = REGTEST_ENDPOINT + 'transaction/details/{}'
+
     @classmethod
     def get_balance(cls, address):
         r = requests.get(cls.MAIN_ADDRESS_API.format(address),
@@ -106,6 +115,15 @@ class BitcoinDotComAPI():
         balance = data['balanceSat'] + data['unconfirmedBalanceSat']
         return balance
 
+    @classmethod
+    def get_balance_regtest(cls, address):
+        r = requests.get(cls.REGTEST_ADDRESS_API.format(address),
+                         timeout=DEFAULT_TIMEOUT)
+        r.raise_for_status()  # pragma: no cover
+        data = r.json()
+        balance = data['balanceSat'] + data['unconfirmedBalanceSat']
+        return balance
+
     @classmethod
     def get_transactions(cls, address):
         r = requests.get(cls.MAIN_ADDRESS_API.format(address),
@@ -120,6 +138,13 @@ class BitcoinDotComAPI():
         r.raise_for_status()  # pragma: no cover
         return r.json()['transactions']
 
+    @classmethod
+    def get_transactions_regtest(cls, address):
+        r = requests.get(cls.REGTEST_ADDRESS_API.format(address),
+                         timeout=DEFAULT_TIMEOUT)
+        r.raise_for_status()  # pragma: no cover
+        return r.json()['transactions']
+
     @classmethod
     def get_transaction(cls, txid):
         r = requests.get(cls.MAIN_TX_API.format(txid),
@@ -186,6 +211,39 @@ class BitcoinDotComAPI():
 
         return tx
 
+    @classmethod
+    def get_transaction_regtest(cls, txid):
+        r = requests.get(cls.REGTEST_TX_API.format(txid),
+                         timeout=DEFAULT_TIMEOUT)
+        r.raise_for_status()  # pragma: no cover
+        response = r.json(parse_float=Decimal)
+
+        tx = Transaction(response['txid'], response['blockheight'],
+                         (Decimal(response['valueIn']) *
+                          BCH_TO_SAT_MULTIPLIER).normalize(),
+                         (Decimal(response['valueOut']) *
+                          BCH_TO_SAT_MULTIPLIER).normalize(),
+                         (Decimal(response['fees']) * BCH_TO_SAT_MULTIPLIER).normalize())
+
+        for txin in response['vin']:
+            part = TxPart(txin['cashAddress'],
+                          txin['value'],
+                          txin['scriptSig']['asm'])
+            tx.add_input(part)
+
+        for txout in response['vout']:
+            addr = None
+            if 'cashAddrs' in txout['scriptPubKey'] and txout['scriptPubKey']['cashAddrs'] is not None:
+                addr = txout['scriptPubKey']['cashAddrs'][0]
+
+            part = TxPart(addr,
+                          (Decimal(txout['value']) *
+                           BCH_TO_SAT_MULTIPLIER).normalize(),
+                          txout['scriptPubKey']['asm'])
+            tx.add_output(part)
+
+        return tx
+
     @classmethod
     def get_tx_amount(cls, txid, txindex):
         r = requests.get(cls.MAIN_TX_AMOUNT_API.format(
@@ -194,6 +252,14 @@ class BitcoinDotComAPI():
         response = r.json(parse_float=Decimal)
         return (Decimal(response['vout'][txindex]['value']) * BCH_TO_SAT_MULTIPLIER).normalize()
 
+    @classmethod
+    def get_tx_amount_regtest(cls, txid, txindex):
+        r = requests.get(cls.REGTEST_TX_AMOUNT_API.format(
+            txid), timeout=DEFAULT_TIMEOUT)
+        r.raise_for_status()  # pragma: no cover
+        response = r.json(parse_float=Decimal)
+        return (Decimal(response['vout'][txindex]['value']) * BCH_TO_SAT_MULTIPLIER).normalize()
+
     @classmethod
     def get_unspent(cls, address):
         r = requests.get(cls.MAIN_UNSPENT_API.format(address),
@@ -222,6 +288,20 @@ class BitcoinDotComAPI():
             for tx in r.json()['utxos']
         ]
 
+    @classmethod
+    def get_unspent_regtest(cls, address):
+        r = requests.get(cls.REGTEST_UNSPENT_API.format(address),
+                         timeout=DEFAULT_TIMEOUT)
+        r.raise_for_status()  # pragma: no cover
+        return [
+            Unspent(currency_to_satoshi(tx['amount'], 'bch'),
+                    tx['confirmations'],
+                    r.json()['scriptPubKey'],
+                    tx['txid'],
+                    tx['vout'])
+            for tx in r.json()['utxos']
+        ]
+
     @classmethod
     def get_raw_transaction(cls, txid):
         r = requests.get(cls.MAIN_RAW_API.format(
@@ -238,6 +318,14 @@ class BitcoinDotComAPI():
         response = r.json(parse_float=Decimal)
         return response
 
+    @classmethod
+    def get_raw_transaction_regtest(cls, txid):
+        r = requests.get(cls.REGTEST_RAW_API.format(
+            txid), timeout=DEFAULT_TIMEOUT)
+        r.raise_for_status()  # pragma: no cover
+        response = r.json(parse_float=Decimal)
+        return response
+
     @classmethod
     def broadcast_tx(cls, tx_hex):  # pragma: no cover
         r = requests.get(cls.MAIN_TX_PUSH_API.format(tx_hex))
@@ -248,6 +336,11 @@ class BitcoinDotComAPI():
         r = requests.get(cls.TEST_TX_PUSH_API.format(tx_hex))
         return True if r.status_code == 200 else False
 
+    @classmethod
+    def broadcast_tx_regtest(cls, tx_hex):  # pragma: no cover
+        r = requests.get(cls.REGTEST_TX_PUSH_API.format(tx_hex))
+        return True if r.status_code == 200 else False
+
 
 class BitcoreAPI(InsightAPI):
     """ Insight API v8 """
@@ -395,6 +488,15 @@ class NetworkAPI:
     GET_TX_AMOUNT_TEST = [BitcoreAPI.get_tx_amount_testnet]
     GET_RAW_TX_TEST = [BitcoinDotComAPI.get_raw_transaction_testnet]
 
+    # Regtest
+    GET_BALANCE_REGTEST = [BitcoinDotComAPI.get_balance_regtest]
+    GET_TRANSACTIONS_REGTEST = [BitcoinDotComAPI.get_transactions_regtest]
+    GET_UNSPENT_REGTEST = [BitcoinDotComAPI.get_unspent_regtest]
+    BROADCAST_TX_REGTEST = [BitcoinDotComAPI.broadcast_tx_regtest]
+    GET_TX_REGTEST = [BitcoinDotComAPI.get_transaction_regtest]
+    GET_TX_AMOUNT_REGTEST = [BitcoinDotComAPI.get_tx_amount_regtest]
+    GET_RAW_TX_REGTEST = [BitcoinDotComAPI.get_raw_transaction_regtest]
+
     @classmethod
     def get_balance(cls, address):
         """Gets the balance of an address in satoshi.
@@ -431,6 +533,24 @@ class NetworkAPI:
 
         raise ConnectionError('All APIs are unreachable.')
 
+    @classmethod
+    def get_balance_regtest(cls, address):
+        """Gets the balance of an address on the regtest network in satoshi.
+
+        :param address: The address in question.
+        :type address: ``str``
+        :raises ConnectionError: If all API services fail.
+        :rtype: ``int``
+        """
+
+        for api_call in cls.GET_BALANCE_REGTEST:
+            try:
+                return api_call(address)
+            except cls.IGNORED_ERRORS:
+                pass
+
+        raise ConnectionError('All APIs are unreachable.')
+
     @classmethod
     def get_transactions(cls, address):
         """Gets the ID of all transactions related to an address.
@@ -468,6 +588,25 @@ class NetworkAPI:
 
         raise ConnectionError('All APIs are unreachable.')
 
+    @classmethod
+    def get_transactions_regtest(cls, address):
+        """Gets the ID of all transactions related to an address on the
+        regtest network.
+
+        :param address: The address in question.
+        :type address: ``str``
+        :raises ConnectionError: If all API services fail.
+        :rtype: ``list`` of ``str``
+        """
+
+        for api_call in cls.GET_TRANSACTIONS_REGTEST:
+            try:
+                return api_call(address)
+            except cls.IGNORED_ERRORS:
+                pass
+
+        raise ConnectionError('All APIs are unreachable.')
+
     @classmethod
     def get_transaction(cls, txid):
         """Gets the full transaction details.
@@ -505,6 +644,25 @@ class NetworkAPI:
 
         raise ConnectionError('All APIs are unreachable.')
 
+    @classmethod
+    def get_transaction_regtest(cls, txid):
+        """Gets the full transaction details on the regtest
+        network.
+
+        :param txid: The transaction id in question.
+        :type txid: ``str``
+        :raises ConnectionError: If all API services fail.
+        :rtype: ``Transaction``
+        """
+
+        for api_call in cls.GET_TX_REGTEST:
+            try:
+                return api_call(txid)
+            except cls.IGNORED_ERRORS:
+                pass
+
+        raise ConnectionError('All APIs are unreachable.')
+
     @classmethod
     def get_tx_amount(cls, txid, txindex):
         """Gets the amount of a given transaction output.
@@ -546,6 +704,27 @@ class NetworkAPI:
 
         raise ConnectionError('All APIs are unreachable.')
 
+    @classmethod
+    def get_tx_amount_regtest(cls, txid, txindex):
+        """Gets the amount of a given transaction output on the
+        regtest network.
+
+        :param txid: The transaction id in question.
+        :type txid: ``str``
+        :param txindex: The transaction index in question.
+        :type txindex: ``int``
+        :raises ConnectionError: If all API services fail.
+        :rtype: ``Decimal``
+        """
+
+        for api_call in cls.GET_TX_AMOUNT_REGTEST:
+            try:
+                return api_call(txid, txindex)
+            except cls.IGNORED_ERRORS:
+                pass
+
+        raise ConnectionError('All APIs are unreachable.')
+
     @classmethod
     def get_unspent(cls, address):
         """Gets all unspent transaction outputs belonging to an address.
@@ -583,6 +762,25 @@ class NetworkAPI:
 
         raise ConnectionError('All APIs are unreachable.')
 
+    @classmethod
+    def get_unspent_regtest(cls, address):
+        """Gets all unspent transaction outputs belonging to an address on the
+        regtest network.
+
+        :param address: The address in question.
+        :type address: ``str``
+        :raises ConnectionError: If all API services fail.
+        :rtype: ``list`` of :class:`~bitcash.network.meta.Unspent`
+        """
+
+        for api_call in cls.GET_UNSPENT_REGTEST:
+            try:
+                return api_call(address)
+            except cls.IGNORED_ERRORS:
+                pass
+
+        raise ConnectionError('All APIs are unreachable.')
+
     @classmethod
     def get_raw_transaction(cls, txid):
         """Gets the raw, unparsed transaction details.
@@ -620,6 +818,25 @@ class NetworkAPI:
 
         raise ConnectionError('All APIs are unreachable.')
 
+    @classmethod
+    def get_raw_transaction_regtest(cls, txid):
+        """Gets the raw, unparsed transaction details on the regtest
+        network.
+
+        :param txid: The transaction id in question.
+        :type txid: ``str``
+        :raises ConnectionError: If all API services fail.
+        :rtype: ``Transaction``
+        """
+
+        for api_call in cls.GET_RAW_TX_REGTEST:
+            try:
+                return api_call(txid)
+            except cls.IGNORED_ERRORS:
+                pass
+
+        raise ConnectionError('All APIs are unreachable.')
+
     @classmethod
     def broadcast_tx(cls, tx_hex):  # pragma: no cover
         """Broadcasts a transaction to the blockchain.
@@ -669,3 +886,28 @@ class NetworkAPI:
                                   'Unspents were already used.')
 
         raise ConnectionError('All APIs are unreachable.')
+
+    @classmethod
+    def broadcast_tx_regtest(cls, tx_hex):  # pragma: no cover
+        """Broadcasts a transaction to the regtest network's blockchain.
+
+        :param tx_hex: A signed transaction in hex form.
+        :type tx_hex: ``str``
+        :raises ConnectionError: If all API services fail.
+        """
+        success = None
+
+        for api_call in cls.BROADCAST_TX_REGTEST:
+            try:
+                success = api_call(tx_hex)
+                if not success:
+                    continue
+                return
+            except cls.IGNORED_ERRORS:
+                pass
+
+        if success is False:
+            raise ConnectionError('Transaction broadcast failed, or '
+                                  'Unspents were already used.')
+
+        raise ConnectionError('All APIs are unreachable.')
