@@ -14,19 +14,24 @@ from bitcash.transaction import (
     )
 
 
-def wif_to_key(wif):
-    private_key_bytes, compressed, version = wif_to_bytes(wif)
-
+def wif_to_key(wif, regtest=False):
+    private_key_bytes, compressed, version = wif_to_bytes(wif, regtest)
+    
     if version == 'main':
         if compressed:
             return PrivateKey.from_bytes(private_key_bytes)
         else:
             return PrivateKey(wif)
-    else:
+    elif version == 'test':
         if compressed:
             return PrivateKeyTestnet.from_bytes(private_key_bytes)
         else:
             return PrivateKeyTestnet(wif)
+    else:  # Regtest
+        if compressed:
+            return PrivateKeyRegtest.from_bytes(private_key_bytes)
+        else:
+            return PrivateKeyRegtest(wif)
 
 
 class BaseKey:
@@ -41,10 +46,10 @@ class BaseKey:
     :type wif: ``str``
     :raises TypeError: If ``wif`` is not a ``str``.
     """
-    def __init__(self, wif=None):
+    def __init__(self, wif=None, regtest=False):
         if wif:
             if isinstance(wif, str):
-                private_key_bytes, compressed, version = wif_to_bytes(wif)
+                private_key_bytes, compressed, version = wif_to_bytes(wif, regtest)
                 self._pk = ECPrivateKey(private_key_bytes)
             elif isinstance(wif, ECPrivateKey):
                 self._pk = wif
@@ -714,4 +719,300 @@ class PrivateKeyTestnet(BaseKey):
         return '<PrivateKeyTestnet: {}>'.format(self.address)
 
 
+class PrivateKeyRegtest(BaseKey):
+    """This class represents a regtest BitcoinCash private key. **Note:** coins
+    on the regtest network have no monetary value!
+
+    :param wif: A private key serialized to the Wallet Import Format. If the
+                argument is not supplied, a new private key will be created.
+                The WIF compression flag will be adhered to, but the version
+                byte is disregarded. Compression will be used by all new keys.
+    :type wif: ``str``
+    :raises TypeError: If ``wif`` is not a ``str``.
+    """
+
+    def __init__(self, wif=None, regtest=True):
+        super().__init__(wif, regtest)
+
+        self._address = None
+        self._scriptcode = None
+
+        self.balance = 0
+        self.unspents = []
+        self.transactions = []
+
+    @property
+    def address(self):
+        """The public address you share with others to receive funds."""
+        if self._address is None:
+            self._address = public_key_to_address(self._public_key, version='regtest')
+
+        return self._address
+
+    @property
+    def scriptcode(self):
+        self._scriptcode = (OP_DUP + OP_HASH160 + OP_PUSH_20 +
+                            address_to_public_key_hash(self.address) +
+                            OP_EQUALVERIFY + OP_CHECKSIG)
+        return self._scriptcode
+
+    def to_wif(self):
+        return bytes_to_wif(
+            self._pk.secret,
+            version='regtest',
+            compressed=self.is_compressed()
+        )
+
+    def balance_as(self, currency):
+        """Returns your balance as a formatted string in a particular currency.
+
+        :param currency: One of the :ref:`supported currencies`.
+        :type currency: ``str``
+        :rtype: ``str``
+        """
+        return satoshi_to_currency_cached(self.balance, currency)
+
+    def get_balance(self, currency='satoshi'):
+        """Fetches the current balance by calling
+        :func:`~bitcash.PrivateKeyTestnet.get_unspents`.
+        We do not use `~bitcash.PrivateKeyTestnet.balance_as` as Testnet coins
+        do not have a fiat (e.g. USD) value.
+
+        :param currency: One of the :ref:`supported currencies`.
+        :type currency: ``str``
+        :rtype: ``str``
+        """
+        self.unspents[:] = NetworkAPI.get_unspent_regtest(self.address)
+        self.balance = sum(unspent.amount for unspent in self.unspents)
+        return self.balance
+
+    def get_unspents(self):
+        """Fetches all available unspent transaction outputs.
+
+        :rtype: ``list`` of :class:`~bitcash.network.meta.Unspent`
+        """
+        self.unspents[:] = NetworkAPI.get_unspent_regtest(self.address)
+        self.balance = sum(unspent.amount for unspent in self.unspents)
+        return self.unspents
+
+    def get_transactions(self):
+        """Fetches transaction history.
+
+        :rtype: ``list`` of ``str`` transaction IDs
+        """
+        self.transactions[:] = NetworkAPI.get_transactions_regtest(self.address)
+        return self.transactions
+
+    def create_transaction(self, outputs, fee=None, leftover=None, combine=True,
+                           message=None, unspents=None, custom_pushdata=False):
+        """Creates a signed P2PKH transaction.
+
+        :param outputs: A sequence of outputs you wish to send in the form
+                        ``(destination, amount, currency)``. The amount can
+                        be either an int, float, or string as long as it is
+                        a valid input to ``decimal.Decimal``. The currency
+                        must be :ref:`supported <supported currencies>`.
+        :type outputs: ``list`` of ``tuple``
+        :param fee: The number of satoshi per byte to pay to miners. By default
+                    Bitcash will poll `<https://bitcoincashfees.earn.com>`_ and use a fee
+                    that will allow your transaction to be confirmed as soon as
+                    possible.
+        :type fee: ``int``
+        :param leftover: The destination that will receive any change from the
+                         transaction. By default Bitcash will send any change to
+                         the same address you sent from.
+        :type leftover: ``str``
+        :param combine: Whether or not Bitcash should use all available UTXOs to
+                        make future transactions smaller and therefore reduce
+                        fees. By default Bitcash will consolidate UTXOs.
+        :type combine: ``bool``
+        :param message: A message to include in the transaction. This will be
+                        stored in the blockchain forever. Due to size limits,
+                        each message will be stored in chunks of 220 bytes.
+        :type message: ``str``
+        :param unspents: The UTXOs to use as the inputs. By default Bitcash will
+                         communicate with the testnet blockchain itself.
+        :type unspents: ``list`` of :class:`~bitcash.network.meta.Unspent`
+        :returns: The signed transaction as hex.
+        :rtype: ``str``
+        """
+
+        unspents, outputs = sanitize_tx_data(
+            unspents or self.unspents,
+            outputs,
+            fee or get_fee(),
+            leftover or self.address,
+            combine=combine,
+            message=message,
+            compressed=self.is_compressed(),
+            custom_pushdata=custom_pushdata,
+        )
+
+        return create_p2pkh_transaction(self, unspents, outputs, custom_pushdata=custom_pushdata)
+
+    def send(self, outputs, fee=None, leftover=None, combine=True,
+             message=None, unspents=None):
+        """Creates a signed P2PKH transaction and attempts to broadcast it on
+        the testnet blockchain. This accepts the same arguments as
+        :func:`~bitcash.PrivateKeyTestnet.create_transaction`.
+
+        :param outputs: A sequence of outputs you wish to send in the form
+                        ``(destination, amount, currency)``. The amount can
+                        be either an int, float, or string as long as it is
+                        a valid input to ``decimal.Decimal``. The currency
+                        must be :ref:`supported <supported currencies>`.
+        :type outputs: ``list`` of ``tuple``
+        :param fee: The number of satoshi per byte to pay to miners. By default
+                    Bitcash will poll `<https://bitcoincashfees.earn.com>`_ and use a fee
+                    that will allow your transaction to be confirmed as soon as
+                    possible.
+        :type fee: ``int``
+        :param leftover: The destination that will receive any change from the
+                         transaction. By default Bitcash will send any change to
+                         the same address you sent from.
+        :type leftover: ``str``
+        :param combine: Whether or not Bitcash should use all available UTXOs to
+                        make future transactions smaller and therefore reduce
+                        fees. By default Bitcash will consolidate UTXOs.
+        :type combine: ``bool``
+        :param message: A message to include in the transaction. This will be
+                        stored in the blockchain forever. Due to size limits,
+                        each message will be stored in chunks of 220 bytes.
+        :type message: ``str``
+        :param unspents: The UTXOs to use as the inputs. By default Bitcash will
+                         communicate with the testnet blockchain itself.
+        :type unspents: ``list`` of :class:`~bitcash.network.meta.Unspent`
+        :returns: The transaction ID.
+        :rtype: ``str``
+        """
+
+        tx_hex = self.create_transaction(
+            outputs, fee=fee, leftover=leftover, combine=combine, message=message, unspents=unspents
+        )
+
+        NetworkAPI.broadcast_tx_regtest(tx_hex)
+
+        return calc_txid(tx_hex)
+
+    @classmethod
+    def prepare_transaction(cls, address, outputs, compressed=True, fee=None, leftover=None,
+                            combine=True, message=None, unspents=None):
+        """Prepares a P2PKH transaction for offline signing.
+
+        :param address: The address the funds will be sent from.
+        :type address: ``str``
+        :param outputs: A sequence of outputs you wish to send in the form
+                        ``(destination, amount, currency)``. The amount can
+                        be either an int, float, or string as long as it is
+                        a valid input to ``decimal.Decimal``. The currency
+                        must be :ref:`supported <supported currencies>`.
+        :type outputs: ``list`` of ``tuple``
+        :param compressed: Whether or not the ``address`` corresponds to a
+                           compressed public key. This influences the fee.
+        :type compressed: ``bool``
+        :param fee: The number of satoshi per byte to pay to miners. By default
+                    Bitcash will poll `<https://bitcoincashfees.earn.com>`_ and use a fee
+                    that will allow your transaction to be confirmed as soon as
+                    possible.
+        :type fee: ``int``
+        :param leftover: The destination that will receive any change from the
+                         transaction. By default Bitcash will send any change to
+                         the same address you sent from.
+        :type leftover: ``str``
+        :param combine: Whether or not Bitcash should use all available UTXOs to
+                        make future transactions smaller and therefore reduce
+                        fees. By default Bitcash will consolidate UTXOs.
+        :type combine: ``bool``
+        :param message: A message to include in the transaction. This will be
+                        stored in the blockchain forever. Due to size limits,
+                        each message will be stored in chunks of 220 bytes.
+        :type message: ``str``
+        :param unspents: The UTXOs to use as the inputs. By default Bitcash will
+                         communicate with the blockchain itself.
+        :type unspents: ``list`` of :class:`~bitcash.network.meta.Unspent`
+        :returns: JSON storing data required to create an offline transaction.
+        :rtype: ``str``
+        """
+        unspents, outputs = sanitize_tx_data(
+            unspents or NetworkAPI.get_unspent_regtest(address),
+            outputs,
+            fee or get_fee(),
+            leftover or address,
+            combine=combine,
+            message=message,
+            compressed=compressed,
+        )
+
+        data = {
+            'unspents': [unspent.to_dict() for unspent in unspents],
+            'outputs': outputs
+        }
+
+        return json.dumps(data, separators=(',', ':'))
+
+    def sign_transaction(self, tx_data):
+        """Creates a signed P2PKH transaction using previously prepared
+        transaction data.
+
+        :param tx_data: Output of :func:`~bitcash.PrivateKeyRegtest.prepare_transaction`.
+        :type tx_data: ``str``
+        :returns: The signed transaction as hex.
+        :rtype: ``str``
+        """
+        data = json.loads(tx_data)
+
+        unspents = [Unspent.from_dict(unspent) for unspent in data['unspents']]
+        outputs = data['outputs']
+
+        return create_p2pkh_transaction(self, unspents, outputs)
+
+    @classmethod
+    def from_hex(cls, hexed):
+        """
+        :param hexed: A private key previously encoded as hex.
+        :type hexed: ``str``
+        :rtype: :class:`~bitcash.PrivateKeyRegtest`
+        """
+        return PrivateKeyRegtest(ECPrivateKey.from_hex(hexed))
+
+    @classmethod
+    def from_bytes(cls, bytestr):
+        """
+        :param bytestr: A private key previously encoded as hex.
+        :type bytestr: ``bytes``
+        :rtype: :class:`~bitcash.PrivateKeyRegtest`
+        """
+        return PrivateKeyRegtest(ECPrivateKey(bytestr))
+
+    @classmethod
+    def from_der(cls, der):
+        """
+        :param der: A private key previously encoded as DER.
+        :type der: ``bytes``
+        :rtype: :class:`~bitcash.PrivateKeyRegtest`
+        """
+        return PrivateKeyRegtest(ECPrivateKey.from_der(der))
+
+    @classmethod
+    def from_pem(cls, pem):
+        """
+        :param pem: A private key previously encoded as PEM.
+        :type pem: ``bytes``
+        :rtype: :class:`~bitcash.PrivateKeyRegtest`
+        """
+        return PrivateKeyRegtest(ECPrivateKey.from_pem(pem))
+
+    @classmethod
+    def from_int(cls, num):
+        """
+        :param num: A private key in raw integer form.
+        :type num: ``int``
+        :rtype: :class:`~bitcash.PrivateKeyRegtest`
+        """
+        return PrivateKeyRegtest(ECPrivateKey.from_int(num))
+
+    def __repr__(self):
+        return '<PrivateKeyRegtest: {}>'.format(self.address)
+
+
 Key = PrivateKey
